=== modified file 'bzrlib/transport/__init__.py'
--- bzrlib/transport/__init__.py	2006-01-20 09:06:19 +0000
+++ bzrlib/transport/__init__.py	2006-01-20 22:45:36 +0000
@@ -334,7 +334,6 @@
 
         return self._iterate_over(relpaths, copy_entry, pb, 'copy_to', expand=False)
 
-
     def move(self, rel_from, rel_to):
         """Move the item at rel_from to the location at rel_to.
         

=== modified file 'bzrlib/upgrade.py'
--- bzrlib/upgrade.py	2006-01-20 09:06:19 +0000
+++ bzrlib/upgrade.py	2006-01-20 22:45:36 +0000
@@ -65,22 +65,25 @@
 # the moment saves us having to worry about when files need new
 # versions.
 
-
+from cStringIO import StringIO
 import os
 import tempfile
 import sys
 from stat import *
 
-from bzrlib.atomicfile import AtomicFile
 from bzrlib.branch import Branch, find_branch
 from bzrlib.branch import BZR_BRANCH_FORMAT_5, BZR_BRANCH_FORMAT_6
-from bzrlib.branch import BzrBranchFormat4, BzrBranchFormat5, BzrBranchFormat6
-from bzrlib.errors import UpgradeReadonly
+from bzrlib.branch import BzrBranchFormat, BzrBranchFormat4, BzrBranchFormat5, BzrBranchFormat6
+from bzrlib.errors import NoSuchFile, UpgradeReadonly
 import bzrlib.hashcache as hashcache
 from bzrlib.osutils import sha_strings, sha_string, pathjoin, abspath
 from bzrlib.ui import ui_factory
+from bzrlib.store.text import TextStore
+from bzrlib.store.weave import WeaveStore
 from bzrlib.trace import mutter, note, warning
+from bzrlib.transactions import PassThroughTransaction
 from bzrlib.transport import get_transport
+from bzrlib.transport.local import LocalTransport
 from bzrlib.weave import Weave
 from bzrlib.weavefile import read_weave, write_weave
 from bzrlib.xml4 import serializer_v4
@@ -109,41 +112,53 @@
         if isinstance(self.old_format, BzrBranchFormat4):
             note('starting upgrade from format 4 to 5')
             self._convert_to_weaves()
-            self._open_branch()
         if isinstance(self.old_format, BzrBranchFormat5):
             note('starting upgrade from format 5 to 6')
             self._convert_to_prefixed()
-            self._open_branch()
-        cache = hashcache.HashCache(abspath(self.base))
-        cache.clear()
-        cache.write()
+        if isinstance(self.transport, LocalTransport):
+            cache = hashcache.HashCache(abspath(self.base))
+            cache.clear()
+            cache.write()
         note("finished")
 
     def _convert_to_prefixed(self):
         from bzrlib.store import hash_prefix
+        bzr_transport = self.transport.clone('.bzr')
+        bzr_transport.delete('branch-format')
         for store_name in ["weaves", "revision-store"]:
             note("adding prefixes to %s" % store_name) 
-            store_dir = pathjoin(self.base, ".bzr", store_name)
-            for filename in os.listdir(store_dir):
+            store_transport = bzr_transport.clone(store_name)
+            for filename in store_transport.list_dir('.'):
                 if filename.endswith(".weave") or filename.endswith(".gz"):
                     file_id = os.path.splitext(filename)[0]
                 else:
                     file_id = filename
-                prefix_dir = pathjoin(store_dir, hash_prefix(file_id))
-                if not os.path.isdir(prefix_dir):
-                    os.mkdir(prefix_dir)
-                os.rename(pathjoin(store_dir, filename),
-                          pathjoin(prefix_dir, filename))
+                prefix_dir = hash_prefix(file_id)
+                # FIXME keep track of the dirs made RBC 20060121
+                try:
+                    store_transport.move(filename, prefix_dir + '/' + filename)
+                except NoSuchFile: # catches missing dirs strangely enough
+                    store_transport.mkdir(prefix_dir)
+                    store_transport.move(filename, prefix_dir + '/' + filename)
         self._set_new_format(BZR_BRANCH_FORMAT_6)
+        self.branch = BzrBranchFormat6().open(self.transport)
+        self.old_format = self.branch._branch_format
 
     def _convert_to_weaves(self):
         note('note: upgrade may be faster if all store files are ungzipped first')
-        if not os.path.isdir(self.base + '/.bzr/weaves'):
-            os.mkdir(self.base + '/.bzr/weaves')
+        bzr_transport = self.transport.clone('.bzr')
+        try:
+            # TODO permissions
+            stat = bzr_transport.stat('weaves')
+            if not S_ISDIR(stat.st_mode):
+                bzr_transport.delete('weaves')
+                bzr_transport.mkdir('weaves')
+        except NoSuchFile:
+            bzr_transport.mkdir('weaves')
         self.inv_weave = Weave('inventory')
         # holds in-memory weaves for all files
         self.text_weaves = {}
-        os.remove(self.branch.controlfilename('branch-format'))
+        bzr_transport.delete('branch-format')
         self._convert_working_inv()
         rev_history = self.branch.revision_history()
         # to_read is a stack holding the revisions we still need to process;
@@ -169,10 +184,12 @@
         note('  %6d texts' % self.text_count)
         self._cleanup_spare_files_after_format4()
         self._set_new_format(BZR_BRANCH_FORMAT_5)
+        self.branch = BzrBranchFormat5().open(self.transport)
+        self.old_format = self.branch._branch_format
 
     def _open_branch(self):
-        self.branch = Branch.open_downlevel(self.base)
-        self.old_format = self.branch._branch_format
+        self.old_format = BzrBranchFormat.find_format(self.transport)
+        self.branch = self.old_format.open(self.transport)
         if isinstance(self.old_format, BzrBranchFormat6):
             note('this branch is in the most current format (%s)', self.old_format)
             return False
@@ -225,33 +242,40 @@
         new_inv_xml = serializer_v5.write_inventory_to_string(inv)
         branch.put_controlfile('inventory', new_inv_xml)
 
-
-
     def _write_all_weaves(self):
-        write_a_weave(self.inv_weave, self.base + '/.bzr/inventory.weave')
+        bzr_transport = self.transport.clone('.bzr')
+        controlweaves = WeaveStore(bzr_transport, prefixed=False)
+        weave_transport = bzr_transport.clone('weaves')
+        weaves = WeaveStore(weave_transport, prefixed=False)
+        transaction = PassThroughTransaction()
+
+        controlweaves.put_weave('inventory', self.inv_weave, transaction)
         i = 0
         try:
             for file_id, file_weave in self.text_weaves.items():
                 self.pb.update('writing weave', i, len(self.text_weaves))
-                write_a_weave(file_weave, self.base + '/.bzr/weaves/%s.weave' % file_id)
+                weaves.put_weave(file_id, file_weave, transaction)
                 i += 1
         finally:
             self.pb.clear()
 
-
     def _write_all_revs(self):
         """Write all revisions out in new form."""
         transport = self.transport.clone('.bzr')
         transport.delete_tree('revision-store')
         transport.mkdir('revision-store')
+        revision_transport = transport.clone('revision-store')
+        # TODO permissions
+        revision_store = TextStore(revision_transport,
+                                   prefixed=False,
+                                   compressed=True)
         try:
             for i, rev_id in enumerate(self.converted_revs):
                 self.pb.update('write revision', i, len(self.converted_revs))
-                f = file(self.base + '/.bzr/revision-store/%s' % rev_id, 'wb')
-                try:
-                    serializer_v5.write_revision(self.revisions[rev_id], f)
-                finally:
-                    f.close()
+                rev_tmp = StringIO()
+                serializer_v5.write_revision(self.revisions[rev_id], rev_tmp)
+                rev_tmp.seek(0)
+                revision_store.add(rev_tmp, rev_id)
         finally:
             self.pb.clear()
 
@@ -410,14 +434,6 @@
         return o
 
 
-def write_a_weave(weave, filename):
-    inv_wf = file(filename, 'wb')
-    try:
-        write_weave(weave, inv_wf)
-    finally:
-        inv_wf.close()
-
-
 def upgrade(url):
     t = get_transport(url)
     Convert(t)

